rename X86FunctionInfo to X86MachineFunctionInfo to match the header file
it is defined in.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@36196 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/X86/X86MachineFunctionInfo.h b/lib/Target/X86/X86MachineFunctionInfo.h
index 4ec3ba3..b8cf1c4 100644
--- a/lib/Target/X86/X86MachineFunctionInfo.h
+++ b/lib/Target/X86/X86MachineFunctionInfo.h
@@ -24,9 +24,9 @@
   FastCall
 };
   
 /// X86FunctionInfo - This class is derived from MachineFunction private
 /// X86 target-specific information for each MachineFunction.
-class X86FunctionInfo : public MachineFunctionInfo {
+class X86MachineFunctionInfo : public MachineFunctionInfo {
   /// ForceFramePointer - True if the function is required to use of frame
   /// pointer for reasons other than it containing dynamic allocation or 
   /// that FP eliminatation is turned off. For example, Cygwin main function
@@ -42,13 +42,13 @@
   NameDecorationStyle DecorationStyle;
   
 public:
-  X86FunctionInfo() : ForceFramePointer(false),
-                      BytesToPopOnReturn(0),
-                      DecorationStyle(None) {}
+  X86MachineFunctionInfo() : ForceFramePointer(false),
+                             BytesToPopOnReturn(0),
+                             DecorationStyle(None) {}
   
-  X86FunctionInfo(MachineFunction &MF) : ForceFramePointer(false),
-                                         BytesToPopOnReturn(0),
-                                         DecorationStyle(None) {}
+  X86MachineFunctionInfo(MachineFunction &MF) : ForceFramePointer(false),
+                                                BytesToPopOnReturn(0),
+                                                DecorationStyle(None) {}
   
   bool getForceFramePointer() const { return ForceFramePointer;} 
   void setForceFramePointer(bool forceFP) { ForceFramePointer = forceFP; }
@@ -24,9 +24,9 @@
 };
   
-/// X86FunctionInfo - This class is derived from MachineFunction private
+/// X86MachineFunctionInfo - This class is derived from MachineFunction private
 /// X86 target-specific information for each MachineFunction.